function [C,m,p]=lag(M,om,F)
%
% function [C,m,p]=lag(M,om,F)
%
% Progetto di rete integrativa (lag)
%
% INPUT
% M: attenuazione di modulo richiesta (M<1)
% om: pulsazione alla quale si richiede l'attenuazione di modulo (default=1)
% F: perdita di fase desiderata in om (F<0, in gradi; default=-5)
%
% OUTPUT
% C: oggetto tf: C= (s/(m*p)+1)/(s/p+1)
% m: fattore m della rete
% p: valore assoluto del polo della rete
%
% @ G. Calafiore, 2005
%
